.. :changelog:

History
-------

0.1.0 (2014-12-11)
---------------------

* First release on PyPI.

0.1.1 (2014-12-15)
---------------------

* Change development status to Alpha.
* Also add contrib module - django_middlewares
